require 'etcd'

resource_name :etcd_client

property :key, kind_of: String, name_property: true
property :value, kind_of: String
property :prev_value, kind_of: String
property :recursive, kind_of: [TrueClass, FalseClass], default: false
property :ttl, kind_of: Integer

def config
  @config ||= node['etcd_client']
end

def etcd
  @etcd ||= Etcd.client(config)
end

load_current_value do
  begin
    value etcd.get(key).value
  rescue Etcd::KeyNotFound
    current_value_does_not_exist!
  end
end

action :get do
  etcd.get(key).value
end

action :get_keys do
  etcd.get(key)
end

action :set do
  etcd.set(key, value: new_resource.value, ttl: new_resource.ttl)
end

action :test_and_set do
  etcd.test_and_set(key, prev_value, value)
end

action :delete do
  etcd.delete(key, recursive: new_resource.recursive)
end
